@@ -1,18 +1,19 @@
 'use strict';
+// TODO: Remove from `core-js@4`
 var DESCRIPTORS = require('../internals/descriptors');
 var addToUnscopables = require('../internals/add-to-unscopables');
 var toObject = require('../internals/to-object');
-var toLength = require('../internals/to-length');
-var defineProperty = require('../internals/object-define-property').f;
+var lengthOfArrayLike = require('../internals/length-of-array-like');
+var defineBuiltInAccessor = require('../internals/define-built-in-accessor');
 
 // `Array.prototype.lastIndex` getter
 // https://github.com/keithamus/proposal-array-last
-if (DESCRIPTORS && !('lastIndex' in [])) {
-  defineProperty(Array.prototype, 'lastIndex', {
+if (DESCRIPTORS) {
+  defineBuiltInAccessor(Array.prototype, 'lastIndex', {
     configurable: true,
     get: function lastIndex() {
       var O = toObject(this);
-      var len = toLength(O.length);
+      var len = lengthOfArrayLike(O);
       return len == 0 ? 0 : len - 1;
     }
   });
