@@ -1,5 +1,5 @@
 'use strict';
 delete global.Observable;
-require('../../packages/core-js');
-// eslint-disable-next-line import/no-unresolved
+require('core-js');
+// eslint-disable-next-line import/no-unresolved -- generated later
 require('../bundles/observables-tests/default').runTests(global.Observable);
