@@ -1,7 +1,8 @@
-import { STRICT } from '../helpers/constants';
+import { DESCRIPTORS, STRICT } from '../helpers/constants';
 
-import splice from 'core-js-pure/features/array/splice';
-import Symbol from 'core-js-pure/features/symbol';
+import Symbol from 'core-js-pure/es/symbol';
+import splice from 'core-js-pure/es/array/splice';
+import defineProperty from 'core-js-pure/es/object/define-property';
 
 QUnit.test('Array#splice', assert => {
   assert.isFunction(splice);
@@ -20,16 +21,23 @@ QUnit.test('Array#splice', assert => {
   array = [1, 2, 3, 4, 5];
   assert.deepEqual(splice(array, 2, 2, 6, 7), [3, 4]);
   assert.deepEqual(array, [1, 2, 6, 7, 5]);
+  // ES6 semantics
+  array = [0, 1, 2];
+  assert.deepEqual(splice(array, 0), [0, 1, 2]);
+  array = [0, 1, 2];
+  assert.deepEqual(splice(array, 1), [1, 2]);
+  array = [0, 1, 2];
+  assert.deepEqual(splice(array, 2), [2]);
   if (STRICT) {
+    if (DESCRIPTORS) {
+      assert.throws(() => splice(defineProperty([1, 2, 3], 'length', { writable: false }), 1, 1), TypeError, 'non-writable length');
+    }
     assert.throws(() => splice(null), TypeError);
     assert.throws(() => splice(undefined), TypeError);
   }
-  assert.deepEqual(splice({
-    length: -1,
-    0: 1,
-  }), [], 'uses ToLength');
   array = [];
-  array.constructor = { [Symbol.species]: function () { // eslint-disable-line object-shorthand
+  // eslint-disable-next-line object-shorthand -- constructor
+  array.constructor = { [Symbol.species]: function () {
     return { foo: 1 };
   } };
   assert.same(splice(array).foo, 1, '@@species');
