@@ -1,6 +1,6 @@
 import { WHITESPACES } from '../helpers/constants';
 
-import parseFloat from 'core-js-pure/features/number/parse-float';
+import parseFloat from 'core-js-pure/es/number/parse-float';
 
 QUnit.test('Number.parseFloat', assert => {
   assert.isFunction(parseFloat);
@@ -15,4 +15,10 @@ QUnit.test('Number.parseFloat', assert => {
   assert.same(parseFloat(`${ WHITESPACES }-0`), -0);
   assert.same(parseFloat(null), NaN);
   assert.same(parseFloat(undefined), NaN);
+
+  /* eslint-disable es-x/no-symbol -- safe */
+  if (typeof Symbol == 'function') {
+    assert.throws(() => parseFloat(Symbol()), 'throws on symbol argument');
+    assert.throws(() => parseFloat(Object(Symbol())), 'throws on boxed symbol argument');
+  }
 });
