@@ -1,5 +1,5 @@
 import { WHITESPACES } from '../helpers/constants';
-import parseFloat from 'core-js-pure/features/parse-float';
+import parseFloat from 'core-js-pure/es/parse-float';
 
 QUnit.test('parseFloat', assert => {
   assert.isFunction(parseFloat);
@@ -14,4 +14,10 @@ QUnit.test('parseFloat', assert => {
   assert.same(parseFloat(`${ WHITESPACES }-0`), -0);
   assert.same(parseFloat(null), NaN);
   assert.same(parseFloat(undefined), NaN);
+
+  /* eslint-disable es-x/no-symbol -- safe */
+  if (typeof Symbol == 'function') {
+    assert.throws(() => parseFloat(Symbol()), 'throws on symbol argument');
+    assert.throws(() => parseFloat(Object(Symbol())), 'throws on boxed symbol argument');
+  }
 });
