@@ -1,9 +1,10 @@
-import { AggregateError, Promise } from 'core-js-pure/es';
+import AggregateError from 'core-js-pure/es/aggregate-error';
+import Promise from 'core-js-pure/es/promise';
 
 QUnit.test('Promise.any', assert => {
   assert.isFunction(Promise.any);
   assert.arity(Promise.any, 1);
-  assert.ok(Promise.any([1, 2, 3]) instanceof Promise, 'returns a promise');
+  assert.true(Promise.any([1, 2, 3]) instanceof Promise, 'returns a promise');
 });
 
 QUnit.test('Promise.any, resolved', assert => {
@@ -27,7 +28,7 @@ QUnit.test('Promise.any, rejected #1', assert => {
     Promise.reject(2),
     Promise.reject(3),
   ]).catch(error => {
-    assert.ok(error instanceof AggregateError, 'instanceof AggregateError');
+    assert.true(error instanceof AggregateError, 'instanceof AggregateError');
     assert.deepEqual(error.errors, [1, 2, 3], 'rejected with a correct value');
     async();
   });
@@ -37,7 +38,7 @@ QUnit.test('Promise.any, rejected #2', assert => {
   assert.expect(1);
   const async = assert.async();
   Promise.any().catch(() => {
-    assert.ok(true, 'rejected as expected');
+    assert.required('rejected as expected');
     async();
   });
 });
@@ -46,7 +47,7 @@ QUnit.test('Promise.any, rejected #3', assert => {
   assert.expect(2);
   const async = assert.async();
   Promise.any([]).catch(error => {
-    assert.ok(error instanceof AggregateError, 'instanceof AggregateError');
+    assert.true(error instanceof AggregateError, 'instanceof AggregateError');
     assert.deepEqual(error.errors, [], 'rejected with a correct value');
     async();
   });
