@@ -1,8 +1,8 @@
-import AsyncIterator from 'core-js-pure/features/async-iterator';
-
 import { createIterator } from '../helpers/helpers';
 import { STRICT_THIS } from '../helpers/constants';
 
+import AsyncIterator from 'core-js-pure/full/async-iterator';
+
 QUnit.test('AsyncIterator#map', assert => {
   assert.expect(15);
   const async = assert.async();
