@@ -1,8 +1,8 @@
-import Iterator from 'core-js-pure/features/iterator';
-
 import { createIterator } from '../helpers/helpers';
 import { STRICT_THIS } from '../helpers/constants';
 
+import Iterator from 'core-js-pure/full/iterator';
+
 QUnit.test('Iterator#find', assert => {
   const { find } = Iterator.prototype;
 
