@@ -1,15 +1,17 @@
-import { DESCRIPTORS } from '../helpers/constants';
+/* eslint-disable es-x/no-object-getownpropertydescriptor, unicorn/relative-url-style -- required for testing */
+import { DESCRIPTORS, NODE } from '../helpers/constants';
 import urlTestData from '../wpt-url-resources/urltestdata';
 import settersTestData from '../wpt-url-resources/setters';
 import toASCIITestData from '../wpt-url-resources/toascii';
 
-import { URL, URLSearchParams } from 'core-js-pure';
+import URL from 'core-js-pure/stable/url';
+import URLSearchParams from 'core-js-pure/stable/url-search-params';
 
 const { hasOwnProperty } = Object.prototype;
 
 QUnit.test('URL constructor', assert => {
   assert.isFunction(URL);
-  assert.arity(URL, 1);
+  if (!NODE) assert.arity(URL, 1);
 
   assert.same(String(new URL('http://www.domain.com/a/b')), 'http://www.domain.com/a/b');
   assert.same(String(new URL('/c/d', 'http://www.domain.com/a/b')), 'http://www.domain.com/c/d');
@@ -38,14 +40,14 @@ QUnit.test('URL constructor', assert => {
   // assert.same(String(new URL('file://nnsc.nsf.net/bar/baz')), 'file://nnsc.nsf.net/bar/baz', 'file scheme'); // 'file:///bar/baz' in FF
   // assert.same(String(new URL('file://localhost/bar/baz')), 'file:///bar/baz', 'file scheme'); // 'file://localhost/bar/baz' in Chrome
 
-  assert.throws(() => new URL(), 'TypeError: Failed to construct \'URL\': 1 argument required, but only 0 present.');
-  assert.throws(() => new URL(''), 'TypeError: Failed to construct \'URL\': Invalid URL');
-  assert.throws(() => new URL('', 'about:blank'), 'TypeError: Failed to construct \'URL\': Invalid URL');
-  assert.throws(() => new URL('abc'), 'TypeError: Failed to construct \'URL\': Invalid URL');
-  assert.throws(() => new URL('//abc'), 'TypeError: Failed to construct \'URL\': Invalid URL');
-  assert.throws(() => new URL('http:///www.domain.com/', 'abc'), 'TypeError: Failed to construct \'URL\': Invalid base URL');
-  assert.throws(() => new URL('http:///www.domain.com/', null), 'TypeError: Failed to construct \'URL\': Invalid base URL');
-  assert.throws(() => new URL('//abc', null), 'TypeError: Failed to construct \'URL\': Invalid base URL');
+  assert.throws(() => new URL(), 'TypeError: Failed to construct URL: 1 argument required, but only 0 present.');
+  assert.throws(() => new URL(''), 'TypeError: Failed to construct URL: Invalid URL');
+  assert.throws(() => new URL('', 'about:blank'), 'TypeError: Failed to construct URL: Invalid URL');
+  assert.throws(() => new URL('abc'), 'TypeError: Failed to construct URL: Invalid URL');
+  assert.throws(() => new URL('//abc'), 'TypeError: Failed to construct URL: Invalid URL');
+  assert.throws(() => new URL('http:///www.domain.com/', 'abc'), 'TypeError: Failed to construct URL: Invalid base URL');
+  assert.throws(() => new URL('http:///www.domain.com/', null), 'TypeError: Failed to construct URL: Invalid base URL');
+  assert.throws(() => new URL('//abc', null), 'TypeError: Failed to construct URL: Invalid base URL');
   assert.throws(() => new URL('http://[20:0:0:1:0:0:0:ff'), 'incorrect IPv6');
   assert.throws(() => new URL('http://[20:0:0:1:0:0:0:fg]'), 'incorrect IPv6');
   // assert.throws(() => new URL('http://a%b'), 'forbidden host code point'); // no error in FF
@@ -56,10 +58,10 @@ QUnit.test('URL#href', assert => {
   let url = new URL('http://zloirock.ru/');
 
   if (DESCRIPTORS) {
-    assert.ok(!hasOwnProperty.call(url, 'href'));
+    assert.false(hasOwnProperty.call(url, 'href'));
     const descriptor = Object.getOwnPropertyDescriptor(URL.prototype, 'href');
-    assert.same(descriptor.enumerable, true);
-    assert.same(descriptor.configurable, true);
+    assert.true(descriptor.enumerable);
+    assert.true(descriptor.configurable);
     assert.same(typeof descriptor.get, 'function');
     assert.same(typeof descriptor.set, 'function');
   }
@@ -130,10 +132,10 @@ QUnit.test('URL#origin', assert => {
   const url = new URL('http://es6.zloirock.ru/tests.html');
 
   if (DESCRIPTORS) {
-    assert.ok(!hasOwnProperty.call(url, 'origin'));
+    assert.false(hasOwnProperty.call(url, 'origin'));
     const descriptor = Object.getOwnPropertyDescriptor(URL.prototype, 'origin');
-    assert.same(descriptor.enumerable, true);
-    assert.same(descriptor.configurable, true);
+    assert.true(descriptor.enumerable);
+    assert.true(descriptor.configurable);
     assert.same(typeof descriptor.get, 'function');
   }
 
@@ -146,10 +148,10 @@ QUnit.test('URL#protocol', assert => {
   let url = new URL('http://zloirock.ru/');
 
   if (DESCRIPTORS) {
-    assert.ok(!hasOwnProperty.call(url, 'protocol'));
+    assert.false(hasOwnProperty.call(url, 'protocol'));
     const descriptor = Object.getOwnPropertyDescriptor(URL.prototype, 'protocol');
-    assert.same(descriptor.enumerable, true);
-    assert.same(descriptor.configurable, true);
+    assert.true(descriptor.enumerable);
+    assert.true(descriptor.configurable);
     assert.same(typeof descriptor.get, 'function');
     assert.same(typeof descriptor.set, 'function');
   }
@@ -181,10 +183,10 @@ QUnit.test('URL#username', assert => {
   let url = new URL('http://zloirock.ru/');
 
   if (DESCRIPTORS) {
-    assert.ok(!hasOwnProperty.call(url, 'username'));
+    assert.false(hasOwnProperty.call(url, 'username'));
     const descriptor = Object.getOwnPropertyDescriptor(URL.prototype, 'username');
-    assert.same(descriptor.enumerable, true);
-    assert.same(descriptor.configurable, true);
+    assert.true(descriptor.enumerable);
+    assert.true(descriptor.configurable);
     assert.same(typeof descriptor.get, 'function');
     assert.same(typeof descriptor.set, 'function');
   }
@@ -206,10 +208,10 @@ QUnit.test('URL#password', assert => {
   let url = new URL('http://zloirock.ru/');
 
   if (DESCRIPTORS) {
-    assert.ok(!hasOwnProperty.call(url, 'password'));
+    assert.false(hasOwnProperty.call(url, 'password'));
     const descriptor = Object.getOwnPropertyDescriptor(URL.prototype, 'password');
-    assert.same(descriptor.enumerable, true);
-    assert.same(descriptor.configurable, true);
+    assert.true(descriptor.enumerable);
+    assert.true(descriptor.configurable);
     assert.same(typeof descriptor.get, 'function');
     assert.same(typeof descriptor.set, 'function');
   }
@@ -240,10 +242,10 @@ QUnit.test('URL#host', assert => {
   let url = new URL('http://zloirock.ru:81/path');
 
   if (DESCRIPTORS) {
-    assert.ok(!hasOwnProperty.call(url, 'host'));
+    assert.false(hasOwnProperty.call(url, 'host'));
     const descriptor = Object.getOwnPropertyDescriptor(URL.prototype, 'host');
-    assert.same(descriptor.enumerable, true);
-    assert.same(descriptor.configurable, true);
+    assert.true(descriptor.enumerable);
+    assert.true(descriptor.configurable);
     assert.same(typeof descriptor.get, 'function');
     assert.same(typeof descriptor.set, 'function');
   }
@@ -319,10 +321,10 @@ QUnit.test('URL#hostname', assert => {
   let url = new URL('http://zloirock.ru:81/');
 
   if (DESCRIPTORS) {
-    assert.ok(!hasOwnProperty.call(url, 'hostname'));
+    assert.false(hasOwnProperty.call(url, 'hostname'));
     const descriptor = Object.getOwnPropertyDescriptor(URL.prototype, 'hostname');
-    assert.same(descriptor.enumerable, true);
-    assert.same(descriptor.configurable, true);
+    assert.true(descriptor.enumerable);
+    assert.true(descriptor.configurable);
     assert.same(typeof descriptor.get, 'function');
     assert.same(typeof descriptor.set, 'function');
   }
@@ -338,7 +340,7 @@ QUnit.test('URL#hostname', assert => {
     // url = new URL('http://zloirock.ru:81/');
     // url.hostname = 'example.com:82';
     // assert.same(url.hostname, 'example.com'); // '' in Chrome
-    // assert.same(String(url), 'http://example.com:81/'); // 'ttp://example.com:82:81/' in Chrome
+    // assert.same(String(url), 'http://example.com:81/'); // 'http://example.com:82:81/' in Chrome
 
     url = new URL('http://zloirock.ru/foo');
     url.hostname = '測試';
@@ -391,10 +393,10 @@ QUnit.test('URL#port', assert => {
   let url = new URL('http://zloirock.ru:1337/');
 
   if (DESCRIPTORS) {
-    assert.ok(!hasOwnProperty.call(url, 'port'));
+    assert.false(hasOwnProperty.call(url, 'port'));
     const descriptor = Object.getOwnPropertyDescriptor(URL.prototype, 'port');
-    assert.same(descriptor.enumerable, true);
-    assert.same(descriptor.configurable, true);
+    assert.true(descriptor.enumerable);
+    assert.true(descriptor.configurable);
     assert.same(typeof descriptor.get, 'function');
     assert.same(typeof descriptor.set, 'function');
   }
@@ -428,10 +430,10 @@ QUnit.test('URL#pathname', assert => {
   let url = new URL('http://zloirock.ru/foo/bar');
 
   if (DESCRIPTORS) {
-    assert.ok(!hasOwnProperty.call(url, 'pathname'));
+    assert.false(hasOwnProperty.call(url, 'pathname'));
     const descriptor = Object.getOwnPropertyDescriptor(URL.prototype, 'pathname');
-    assert.same(descriptor.enumerable, true);
-    assert.same(descriptor.configurable, true);
+    assert.true(descriptor.enumerable);
+    assert.true(descriptor.configurable);
     assert.same(typeof descriptor.get, 'function');
     assert.same(typeof descriptor.set, 'function');
   }
@@ -450,10 +452,10 @@ QUnit.test('URL#search', assert => {
   let url = new URL('http://zloirock.ru/');
 
   if (DESCRIPTORS) {
-    assert.ok(!hasOwnProperty.call(url, 'search'));
+    assert.false(hasOwnProperty.call(url, 'search'));
     const descriptor = Object.getOwnPropertyDescriptor(URL.prototype, 'search');
-    assert.same(descriptor.enumerable, true);
-    assert.same(descriptor.configurable, true);
+    assert.true(descriptor.enumerable);
+    assert.true(descriptor.configurable);
     assert.same(typeof descriptor.get, 'function');
     assert.same(typeof descriptor.set, 'function');
   }
@@ -483,14 +485,14 @@ QUnit.test('URL#searchParams', assert => {
   let url = new URL('http://zloirock.ru/?foo=bar&bar=baz');
 
   if (DESCRIPTORS) {
-    assert.ok(!hasOwnProperty.call(url, 'searchParams'));
+    assert.false(hasOwnProperty.call(url, 'searchParams'));
     const descriptor = Object.getOwnPropertyDescriptor(URL.prototype, 'searchParams');
-    assert.same(descriptor.enumerable, true);
-    assert.same(descriptor.configurable, true);
+    assert.true(descriptor.enumerable);
+    assert.true(descriptor.configurable);
     assert.same(typeof descriptor.get, 'function');
   }
 
-  assert.ok(url.searchParams instanceof URLSearchParams);
+  assert.true(url.searchParams instanceof URLSearchParams);
   assert.same(url.searchParams.get('foo'), 'bar');
   assert.same(url.searchParams.get('bar'), 'baz');
 
@@ -505,7 +507,7 @@ QUnit.test('URL#searchParams', assert => {
 
     url = new URL('http://zloirock.ru/?foo=bar&bar=baz');
     url.search = '';
-    assert.same(url.searchParams.has('foo'), false);
+    assert.false(url.searchParams.has('foo'));
   }
 });
 
@@ -513,10 +515,10 @@ QUnit.test('URL#hash', assert => {
   let url = new URL('http://zloirock.ru/');
 
   if (DESCRIPTORS) {
-    assert.ok(!hasOwnProperty.call(url, 'hash'));
+    assert.false(hasOwnProperty.call(url, 'hash'));
     const descriptor = Object.getOwnPropertyDescriptor(URL.prototype, 'hash');
-    assert.same(descriptor.enumerable, true);
-    assert.same(descriptor.configurable, true);
+    assert.true(descriptor.enumerable);
+    assert.true(descriptor.configurable);
     assert.same(typeof descriptor.get, 'function');
     assert.same(typeof descriptor.set, 'function');
   }
@@ -592,7 +594,7 @@ QUnit.test('URL.sham', assert => {
   assert.same(URL.sham, DESCRIPTORS ? undefined : true);
 });
 
-// `core-js` URL implementation pass all (exclude some encoding-ralated) tests
+// `core-js` URL implementation pass all (exclude some encoding-related) tests
 // from the next 3 test cases, but URLs from all of popular browsers fail a serious part of tests.
 // Replacing all of them does not looks like a good idea, so next test cases disabled by default.
 
