@@ -9,11 +9,11 @@ if (DESCRIPTORS) QUnit.test('%TypedArrayPrototype%.includes', assert => {
     assert.arity(includes, 1, `${ name }::includes arity is 1`);
     assert.name(includes, 'includes', `${ name }::includes name is 'includes'`);
     assert.looksNative(includes, `${ name }::includes looks native`);
-    assert.same(new TypedArray([1, 1, 1]).includes(1), true);
-    assert.same(new TypedArray([1, 2, 3]).includes(1, 1), false);
-    assert.same(new TypedArray([1, 2, 3]).includes(2, 1), true);
-    assert.same(new TypedArray([1, 2, 3]).includes(2, -1), false);
-    assert.same(new TypedArray([1, 2, 3]).includes(2, -2), true);
+    assert.true(new TypedArray([1, 1, 1]).includes(1));
+    assert.false(new TypedArray([1, 2, 3]).includes(1, 1));
+    assert.true(new TypedArray([1, 2, 3]).includes(2, 1));
+    assert.false(new TypedArray([1, 2, 3]).includes(2, -1));
+    assert.true(new TypedArray([1, 2, 3]).includes(2, -2));
     assert.throws(() => includes.call([1], 1), "isn't generic");
   }
 });
