@@ -9,12 +9,12 @@ QUnit.test('AsyncIterator.from', assert => {
   assert.looksNative(from);
   assert.nonEnumerable(AsyncIterator, 'from');
 
-  assert.ok(AsyncIterator.from([].values()) instanceof AsyncIterator, 'proxy, iterator');
+  assert.true(AsyncIterator.from([].values()) instanceof AsyncIterator, 'proxy, iterator');
 
-  assert.ok(AsyncIterator.from([]) instanceof AsyncIterator, 'proxy, iterable');
+  assert.true(AsyncIterator.from([]) instanceof AsyncIterator, 'proxy, iterable');
 
-  AsyncIterator.from([1, 2, 3]).toArray().then(result => {
-    assert.arrayEqual(result, [1, 2, 3], 'just a proxy');
+  AsyncIterator.from([1, Promise.resolve(2), 3]).toArray().then(result => {
+    assert.arrayEqual(result, [1, 2, 3], 'unwrap promises');
     async();
   });
 
@@ -22,7 +22,7 @@ QUnit.test('AsyncIterator.from', assert => {
     next: () => { /* empty */ },
   });
 
-  assert.same(AsyncIterator.from(asyncIterator), asyncIterator, 'does not wrap AsyncIterator instanses');
+  assert.same(AsyncIterator.from(asyncIterator), asyncIterator, 'does not wrap AsyncIterator instances');
 
   assert.throws(() => from(undefined), TypeError);
   assert.throws(() => from(null), TypeError);
