@@ -10,8 +10,8 @@ QUnit.test('Iterator#every', assert => {
   assert.looksNative(every);
   assert.nonEnumerable(Iterator.prototype, 'every');
 
-  assert.ok(every.call(createIterator([1, 2, 3]), it => typeof it == 'number'), 'basic functionality #1');
-  assert.ok(!every.call(createIterator([1, 2, 3]), it => it % 2), 'basic functionality #2');
+  assert.true(every.call(createIterator([1, 2, 3]), it => typeof it == 'number'), 'basic functionality #1');
+  assert.false(every.call(createIterator([1, 2, 3]), it => it % 2), 'basic functionality #2');
   every.call(createIterator([1]), function (arg) {
     assert.same(this, STRICT_THIS, 'this');
     assert.same(arguments.length, 1, 'arguments length');
