@@ -14,36 +14,36 @@ QUnit.test('WeakSet#deleteAll', assert => {
   const e = [];
 
   let set = new WeakSet([a, b, c]);
-  assert.same(set.deleteAll(a, b), true);
-  assert.ok(!set.has(a));
-  assert.ok(!set.has(b));
-  assert.ok(set.has(c));
-  assert.ok(!set.has(d));
-  assert.ok(!set.has(e));
+  assert.true(set.deleteAll(a, b));
+  assert.false(set.has(a));
+  assert.false(set.has(b));
+  assert.true(set.has(c));
+  assert.false(set.has(d));
+  assert.false(set.has(e));
 
   set = new WeakSet([a, b, c]);
-  assert.same(set.deleteAll(c, d), false);
-  assert.ok(set.has(a));
-  assert.ok(set.has(b));
-  assert.ok(!set.has(c));
-  assert.ok(!set.has(d));
-  assert.ok(!set.has(e));
+  assert.false(set.deleteAll(c, d));
+  assert.true(set.has(a));
+  assert.true(set.has(b));
+  assert.false(set.has(c));
+  assert.false(set.has(d));
+  assert.false(set.has(e));
 
   set = new WeakSet([a, b, c]);
-  assert.same(set.deleteAll(d, e), false);
-  assert.ok(set.has(a));
-  assert.ok(set.has(b));
-  assert.ok(set.has(c));
-  assert.ok(!set.has(d));
-  assert.ok(!set.has(e));
+  assert.false(set.deleteAll(d, e));
+  assert.true(set.has(a));
+  assert.true(set.has(b));
+  assert.true(set.has(c));
+  assert.false(set.has(d));
+  assert.false(set.has(e));
 
   set = new WeakSet([a, b, c]);
-  assert.same(set.deleteAll(), true);
-  assert.ok(set.has(a));
-  assert.ok(set.has(b));
-  assert.ok(set.has(c));
-  assert.ok(!set.has(d));
-  assert.ok(!set.has(e));
+  assert.true(set.deleteAll());
+  assert.true(set.has(a));
+  assert.true(set.has(b));
+  assert.true(set.has(c));
+  assert.false(set.has(d));
+  assert.false(set.has(e));
 
   assert.notThrows(() => !deleteAll.call({ delete() { /* empty */ } }, a, b, c));
   assert.throws(() => deleteAll.call({}, a, b, c), TypeError);
