@@ -1,11 +1,13 @@
-import { DESCRIPTORS } from '../helpers/constants';
+import { DESCRIPTORS, NODE } from '../helpers/constants';
 import { createIterable } from '../helpers/helpers';
 
+const { getPrototypeOf, getOwnPropertyDescriptor } = Object;
+
 QUnit.test('URLSearchParams', assert => {
   assert.isFunction(URLSearchParams);
   assert.arity(URLSearchParams, 0);
   assert.name(URLSearchParams, 'URLSearchParams');
-  assert.looksNative(URLSearchParams);
+  if (!NODE) assert.looksNative(URLSearchParams);
 
   assert.same(String(new URLSearchParams()), '');
   assert.same(String(new URLSearchParams('')), '');
@@ -31,20 +33,20 @@ QUnit.test('URLSearchParams', assert => {
   assert.same(String(new URLSearchParams('a==b')), 'a=%3Db');
 
   let params = new URLSearchParams('a=b');
-  assert.same(params.has('a'), true, 'search params object has name "a"');
-  assert.same(params.has('b'), false, 'search params object has not got name "b"');
+  assert.true(params.has('a'), 'search params object has name "a"');
+  assert.false(params.has('b'), 'search params object has not got name "b"');
 
   params = new URLSearchParams('a=b&c');
-  assert.same(params.has('a'), true, 'search params object has name "a"');
-  assert.same(params.has('c'), true, 'search params object has name "c"');
+  assert.true(params.has('a'), 'search params object has name "a"');
+  assert.true(params.has('c'), 'search params object has name "c"');
 
   params = new URLSearchParams('&a&&& &&&&&a+b=& c&m%c3%b8%c3%b8');
-  assert.same(params.has('a'), true, 'search params object has name "a"');
-  assert.same(params.has('a b'), true, 'search params object has name "a b"');
-  assert.same(params.has(' '), true, 'search params object has name " "');
-  assert.same(params.has('c'), false, 'search params object did not have the name "c"');
-  assert.same(params.has(' c'), true, 'search params object has name " c"');
-  assert.same(params.has('møø'), true, 'search params object has name "møø"');
+  assert.true(params.has('a'), 'search params object has name "a"');
+  assert.true(params.has('a b'), 'search params object has name "a b"');
+  assert.true(params.has(' '), 'search params object has name " "');
+  assert.false(params.has('c'), 'search params object did not have the name "c"');
+  assert.true(params.has(' c'), 'search params object has name " c"');
+  assert.true(params.has('møø'), 'search params object has name "møø"');
 
   params = new URLSearchParams('a=b+c');
   assert.same(params.get('a'), 'b c', 'parse +');
@@ -103,7 +105,7 @@ QUnit.test('URLSearchParams', assert => {
     { input: { '+': '%C2' }, output: [['+', '%C2']], name: 'object with +' },
     { input: { c: 'x', a: '?' }, output: [['c', 'x'], ['a', '?']], name: 'object with two keys' },
     { input: [['c', 'x'], ['a', '?']], output: [['c', 'x'], ['a', '?']], name: 'array with two keys' },
-    // eslint-disable-next-line max-len
+    // eslint-disable-next-line max-len -- ignore
     // !!! { input: { 'a\0b': '42', 'c\uD83D': '23', dሴ: 'foo' }, output: [['a\0b', '42'], ['c\uFFFD', '23'], ['d\u1234', 'foo']], name: 'object with NULL, non-ASCII, and surrogate keys' },
   ];
 
@@ -144,7 +146,7 @@ QUnit.test('URLSearchParams#append', assert => {
   assert.arity(append, 2);
   assert.name(append, 'append');
   assert.enumerable(URLSearchParams.prototype, 'append');
-  assert.looksNative(append);
+  if (!NODE) assert.looksNative(append);
 
   assert.same(new URLSearchParams().append('a', 'b'), undefined, 'void');
 
@@ -179,7 +181,7 @@ QUnit.test('URLSearchParams#append', assert => {
   params.append('second', 2);
   params.append('third', '');
   params.append('first', 10);
-  assert.ok(params.has('first'), 'search params object has name "first"');
+  assert.true(params.has('first'), 'search params object has name "first"');
   assert.same(params.get('first'), '1', 'search params object has name "first" with value "1"');
   assert.same(params.get('second'), '2', 'search params object has name "second" with value "2"');
   assert.same(params.get('third'), '', 'search params object has name "third" with value ""');
@@ -196,7 +198,7 @@ QUnit.test('URLSearchParams#delete', assert => {
   assert.isFunction($delete);
   assert.arity($delete, 1);
   assert.enumerable(URLSearchParams.prototype, 'delete');
-  assert.looksNative($delete);
+  if (!NODE) assert.looksNative($delete);
 
   let params = new URLSearchParams('a=b&c=d');
   params.delete('a');
@@ -220,14 +222,14 @@ QUnit.test('URLSearchParams#delete', assert => {
 
   params = new URLSearchParams();
   params.append('first', 1);
-  assert.same(params.has('first'), true, 'search params object has name "first"');
+  assert.true(params.has('first'), 'search params object has name "first"');
   assert.same(params.get('first'), '1', 'search params object has name "first" with value "1"');
   params.delete('first');
-  assert.same(params.has('first'), false, 'search params object has no "first" name');
+  assert.false(params.has('first'), 'search params object has no "first" name');
   params.append('first', 1);
   params.append('first', 10);
   params.delete('first');
-  assert.same(params.has('first'), false, 'search params object has no "first" name');
+  assert.false(params.has('first'), 'search params object has no "first" name');
 
   if (DESCRIPTORS) {
     let url = new URL('http://example.com/?param1&param2');
@@ -253,7 +255,7 @@ QUnit.test('URLSearchParams#get', assert => {
   assert.arity(get, 1);
   assert.name(get, 'get');
   assert.enumerable(URLSearchParams.prototype, 'get');
-  assert.looksNative(get);
+  if (!NODE) assert.looksNative(get);
 
   let params = new URLSearchParams('a=b&c=d');
   assert.same(params.get('a'), 'b');
@@ -270,7 +272,7 @@ QUnit.test('URLSearchParams#get', assert => {
   assert.same(params.get('a'), '');
 
   params = new URLSearchParams('first=second&third&&');
-  assert.same(params.has('first'), true, 'Search params object has name "first"');
+  assert.true(params.has('first'), 'Search params object has name "first"');
   assert.same(params.get('first'), 'second', 'Search params object has name "first" with value "second"');
   assert.same(params.get('third'), '', 'Search params object has name "third" with the empty value.');
   assert.same(params.get('fourth'), null, 'Search params object has no "fourth" name and value.');
@@ -320,7 +322,7 @@ QUnit.test('URLSearchParams#getAll', assert => {
   assert.arity(getAll, 1);
   assert.name(getAll, 'getAll');
   assert.enumerable(URLSearchParams.prototype, 'getAll');
-  assert.looksNative(getAll);
+  if (!NODE) assert.looksNative(getAll);
 
   let params = new URLSearchParams('a=b&c=d');
   assert.arrayEqual(params.getAll('a'), ['b']);
@@ -352,31 +354,31 @@ QUnit.test('URLSearchParams#has', assert => {
   assert.arity(has, 1);
   assert.name(has, 'has');
   assert.enumerable(URLSearchParams.prototype, 'has');
-  assert.looksNative(has);
+  if (!NODE) assert.looksNative(has);
 
   let params = new URLSearchParams('a=b&c=d');
-  assert.same(params.has('a'), true);
-  assert.same(params.has('c'), true);
-  assert.same(params.has('e'), false);
+  assert.true(params.has('a'));
+  assert.true(params.has('c'));
+  assert.false(params.has('e'));
 
   params = new URLSearchParams('a=b&c=d&a=e');
-  assert.same(params.has('a'), true);
+  assert.true(params.has('a'));
 
   params = new URLSearchParams('=b&c=d');
-  assert.same(params.has(''), true);
+  assert.true(params.has(''));
 
   params = new URLSearchParams('null=a');
-  assert.same(params.has(null), true);
+  assert.true(params.has(null));
 
   params = new URLSearchParams('a=b&c=d&&');
   params.append('first', 1);
   params.append('first', 2);
-  assert.same(params.has('a'), true, 'search params object has name "a"');
-  assert.same(params.has('c'), true, 'search params object has name "c"');
-  assert.same(params.has('first'), true, 'search params object has name "first"');
-  assert.same(params.has('d'), false, 'search params object has no name "d"');
+  assert.true(params.has('a'), 'search params object has name "a"');
+  assert.true(params.has('c'), 'search params object has name "c"');
+  assert.true(params.has('first'), 'search params object has name "first"');
+  assert.false(params.has('d'), 'search params object has no name "d"');
   params.delete('first');
-  assert.same(params.has('first'), false, 'search params object has no name "first"');
+  assert.false(params.has('first'), 'search params object has no name "first"');
 
   assert.throws(() => {
     return new URLSearchParams('').has();
@@ -389,7 +391,7 @@ QUnit.test('URLSearchParams#set', assert => {
   assert.arity(set, 2);
   assert.name(set, 'set');
   assert.enumerable(URLSearchParams.prototype, 'set');
-  assert.looksNative(set);
+  if (!NODE) assert.looksNative(set);
 
   let params = new URLSearchParams('a=b&c=d');
   params.set('a', 'B');
@@ -402,14 +404,14 @@ QUnit.test('URLSearchParams#set', assert => {
   assert.same(String(params), 'a=B&c=d&e=f');
 
   params = new URLSearchParams('a=1&a=2&a=3');
-  assert.same(params.has('a'), true, 'search params object has name "a"');
+  assert.true(params.has('a'), 'search params object has name "a"');
   assert.same(params.get('a'), '1', 'search params object has name "a" with value "1"');
   params.set('first', 4);
-  assert.same(params.has('a'), true, 'search params object has name "a"');
+  assert.true(params.has('a'), 'search params object has name "a"');
   assert.same(params.get('a'), '1', 'search params object has name "a" with value "1"');
   assert.same(String(params), 'a=1&a=2&a=3&first=4');
   params.set('a', 4);
-  assert.same(params.has('a'), true, 'search params object has name "a"');
+  assert.true(params.has('a'), 'search params object has name "a"');
   assert.same(params.get('a'), '4', 'search params object has name "a" with value "4"');
   assert.same(String(params), 'a=4&first=4');
 
@@ -424,7 +426,7 @@ QUnit.test('URLSearchParams#sort', assert => {
   assert.arity(sort, 0);
   assert.name(sort, 'sort');
   assert.enumerable(URLSearchParams.prototype, 'sort');
-  assert.looksNative(sort);
+  if (!NODE) assert.looksNative(sort);
 
   let params = new URLSearchParams('a=1&b=4&a=3&b=2');
   params.sort();
@@ -454,8 +456,22 @@ QUnit.test('URLSearchParams#sort', assert => {
     },
     {
       input: 'z=z&a=a&z=y&a=b&z=x&a=c&z=w&a=d&z=v&a=e&z=u&a=f&z=t&a=g',
-      // eslint-disable-next-line max-len
-      output: [['a', 'a'], ['a', 'b'], ['a', 'c'], ['a', 'd'], ['a', 'e'], ['a', 'f'], ['a', 'g'], ['z', 'z'], ['z', 'y'], ['z', 'x'], ['z', 'w'], ['z', 'v'], ['z', 'u'], ['z', 't']],
+      output: [
+        ['a', 'a'],
+        ['a', 'b'],
+        ['a', 'c'],
+        ['a', 'd'],
+        ['a', 'e'],
+        ['a', 'f'],
+        ['a', 'g'],
+        ['z', 'z'],
+        ['z', 'y'],
+        ['z', 'x'],
+        ['z', 'w'],
+        ['z', 'v'],
+        ['z', 'u'],
+        ['z', 't'],
+      ],
     },
     {
       input: 'bbb&bb&aaa&aa=x&aa=y',
@@ -505,7 +521,7 @@ QUnit.test('URLSearchParams#toString', assert => {
   assert.isFunction(toString);
   assert.arity(toString, 0);
   assert.name(toString, 'toString');
-  assert.looksNative(toString);
+  if (!NODE) assert.looksNative(toString);
 
   let params = new URLSearchParams();
   params.append('a', 'b c');
@@ -604,7 +620,7 @@ QUnit.test('URLSearchParams#forEach', assert => {
   assert.arity(forEach, 1);
   assert.name(forEach, 'forEach');
   assert.enumerable(URLSearchParams.prototype, 'forEach');
-  assert.looksNative(forEach);
+  if (!NODE) assert.looksNative(forEach);
 
   const expectedValues = { a: '1', b: '2', c: '3' };
   let params = new URLSearchParams('a=1&b=2&c=3');
@@ -618,7 +634,7 @@ QUnit.test('URLSearchParams#forEach', assert => {
   assert.same(result, 'abc');
 
   new URL('http://a.b/c').searchParams.forEach(() => {
-    assert.ok(false, 'should not be called');
+    assert.avoid();
   });
 
   // fails in Chrome 66-
@@ -649,7 +665,7 @@ QUnit.test('URLSearchParams#entries', assert => {
   assert.arity(entries, 0);
   assert.name(entries, 'entries');
   assert.enumerable(URLSearchParams.prototype, 'entries');
-  assert.looksNative(entries);
+  if (!NODE) assert.looksNative(entries);
 
   const expectedValues = { a: '1', b: '2', c: '3' };
   let params = new URLSearchParams('a=1&b=2&c=3');
@@ -664,7 +680,7 @@ QUnit.test('URLSearchParams#entries', assert => {
   }
   assert.same(result, 'abc');
 
-  assert.ok(new URL('http://a.b/c').searchParams.entries().next().done, 'should be finished');
+  assert.true(new URL('http://a.b/c').searchParams.entries().next().done, 'should be finished');
 
   // fails in Chrome 66-
   if (DESCRIPTORS) {
@@ -689,6 +705,8 @@ QUnit.test('URLSearchParams#entries', assert => {
     result += key + value;
   }
   assert.same(result, 'a1c3');
+
+  if (DESCRIPTORS) assert.true(getOwnPropertyDescriptor(getPrototypeOf(new URLSearchParams().entries()), 'next').enumerable, 'enumerable .next');
 });
 
 QUnit.test('URLSearchParams#keys', assert => {
@@ -697,7 +715,7 @@ QUnit.test('URLSearchParams#keys', assert => {
   assert.arity(keys, 0);
   assert.name(keys, 'keys');
   assert.enumerable(URLSearchParams.prototype, 'keys');
-  assert.looksNative(keys);
+  if (!NODE) assert.looksNative(keys);
 
   let iterator = new URLSearchParams('a=1&b=2&c=3').keys();
   let result = '';
@@ -707,7 +725,7 @@ QUnit.test('URLSearchParams#keys', assert => {
   }
   assert.same(result, 'abc');
 
-  assert.ok(new URL('http://a.b/c').searchParams.keys().next().done, 'should be finished');
+  assert.true(new URL('http://a.b/c').searchParams.keys().next().done, 'should be finished');
 
   // fails in Chrome 66-
   if (DESCRIPTORS) {
@@ -732,6 +750,8 @@ QUnit.test('URLSearchParams#keys', assert => {
     result += key;
   }
   assert.same(result, 'ac');
+
+  if (DESCRIPTORS) assert.true(getOwnPropertyDescriptor(getPrototypeOf(new URLSearchParams().keys()), 'next').enumerable, 'enumerable .next');
 });
 
 QUnit.test('URLSearchParams#values', assert => {
@@ -740,7 +760,7 @@ QUnit.test('URLSearchParams#values', assert => {
   assert.arity(values, 0);
   assert.name(values, 'values');
   assert.enumerable(URLSearchParams.prototype, 'values');
-  assert.looksNative(values);
+  if (!NODE) assert.looksNative(values);
 
   let iterator = new URLSearchParams('a=1&b=2&c=3').values();
   let result = '';
@@ -750,7 +770,7 @@ QUnit.test('URLSearchParams#values', assert => {
   }
   assert.same(result, '123');
 
-  assert.ok(new URL('http://a.b/c').searchParams.values().next().done, 'should be finished');
+  assert.true(new URL('http://a.b/c').searchParams.values().next().done, 'should be finished');
 
   // fails in Chrome 66-
   if (DESCRIPTORS) {
@@ -775,6 +795,8 @@ QUnit.test('URLSearchParams#values', assert => {
     result += key;
   }
   assert.same(result, '13');
+
+  if (DESCRIPTORS) assert.true(getOwnPropertyDescriptor(getPrototypeOf(new URLSearchParams().values()), 'next').enumerable, 'enumerable .next');
 });
 
 QUnit.test('URLSearchParams#@@iterator', assert => {
@@ -782,7 +804,7 @@ QUnit.test('URLSearchParams#@@iterator', assert => {
   assert.isFunction(entries);
   assert.arity(entries, 0);
   assert.name(entries, 'entries');
-  assert.looksNative(entries);
+  if (!NODE) assert.looksNative(entries);
 
   assert.same(entries, URLSearchParams.prototype.entries);
 
@@ -799,7 +821,7 @@ QUnit.test('URLSearchParams#@@iterator', assert => {
   }
   assert.same(result, 'abc');
 
-  assert.ok(new URL('http://a.b/c').searchParams[Symbol.iterator]().next().done, 'should be finished');
+  assert.true(new URL('http://a.b/c').searchParams[Symbol.iterator]().next().done, 'should be finished');
 
   // fails in Chrome 66-
   if (DESCRIPTORS) {
@@ -824,9 +846,19 @@ QUnit.test('URLSearchParams#@@iterator', assert => {
     result += key + value;
   }
   assert.same(result, 'a1c3');
+
+  if (DESCRIPTORS) assert.true(getOwnPropertyDescriptor(getPrototypeOf(new URLSearchParams()[Symbol.iterator]()), 'next').enumerable, 'enumerable .next');
 });
 
 QUnit.test('URLSearchParams#@@toStringTag', assert => {
   const params = new URLSearchParams('a=b');
   assert.same(({}).toString.call(params), '[object URLSearchParams]');
 });
+
+if (typeof Request == 'function') {
+  QUnit.test('URLSearchParams with Request', assert => {
+    new Request('http://zloirock.ru', { body: new URLSearchParams({ foo: 'baz' }), method: 'POST' }).text().then(text => {
+      assert.same(text, 'foo=baz');
+    }).then(assert.async());
+  });
+}
